export declare const configSchema: {
    $id: string;
    type: string;
    properties: {
        receivingChainIPCPath: {
            type: string;
            description: string;
        };
        receivingChainWsURL: {
            type: string;
            description: string;
        };
        ccuFrequency: {
            type: string;
            description: string;
        };
        encryptedPrivateKey: {
            type: string;
            description: string;
        };
        ccuFee: {
            type: string;
            format: string;
            description: string;
        };
        isSaveCCU: {
            type: string;
            description: string;
        };
        maxCCUSize: {
            type: string;
            description: string;
            minimum: number;
            maximum: number;
        };
        ccuSaveLimit: {
            type: string;
            description: string;
            minimum: number;
        };
        registrationHeight: {
            type: string;
            description: string;
            minimum: number;
        };
        receivingChainID: {
            type: string;
            description: string;
        };
    };
    required: string[];
    default: {
        ccuFrequency: number;
        isSaveCCU: boolean;
        maxCCUSize: number;
        registrationHeight: number;
        ccuSaveLimit: number;
    };
};
export declare const validatorsDataSchema: {
    $id: string;
    type: string;
    required: string[];
    properties: {
        validators: {
            type: string;
            fieldNumber: number;
            items: {
                type: string;
                required: string[];
                properties: {
                    address: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    blsKey: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    bftWeight: {
                        dataType: string;
                        fieldNumber: number;
                    };
                };
            };
        };
        certificateThreshold: {
            dataType: string;
            fieldNumber: number;
        };
        validatorsHash: {
            dataType: string;
            fieldNumber: number;
        };
    };
};
export declare const blockHeadersInfoSchema: {
    $id: string;
    type: string;
    properties: {
        blockHeaders: {
            type: string;
            fieldNumber: number;
            items: {
                $id: string;
                required: string[];
                properties: {
                    signature: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    version: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    timestamp: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    height: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    previousBlockID: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    generatorAddress: {
                        dataType: string;
                        fieldNumber: number;
                        format: string;
                    };
                    transactionRoot: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    assetRoot: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    eventRoot: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    stateRoot: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    maxHeightPrevoted: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    maxHeightGenerated: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    impliesMaxPrevotes: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    validatorsHash: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    aggregateCommit: {
                        type: string;
                        fieldNumber: number;
                        required: string[];
                        properties: {
                            height: {
                                dataType: string;
                                fieldNumber: number;
                            };
                            aggregationBits: {
                                dataType: string;
                                fieldNumber: number;
                            };
                            certificateSignature: {
                                dataType: string;
                                fieldNumber: number;
                            };
                        };
                    };
                };
                type: string;
            };
        };
    };
};
export declare const aggregateCommitsInfoSchema: {
    $id: string;
    type: string;
    properties: {
        aggregateCommits: {
            type: string;
            fieldNumber: number;
            items: {
                $id: string;
                type: string;
                required: string[];
                properties: {
                    height: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    aggregationBits: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    certificateSignature: {
                        dataType: string;
                        minLength: number;
                        maxLength: number;
                        fieldNumber: number;
                    };
                };
            };
        };
    };
};
export declare const validatorsHashPreimageInfoSchema: {
    $id: string;
    type: string;
    properties: {
        validatorsHashPreimage: {
            type: string;
            fieldNumber: number;
            items: {
                $id: string;
                type: string;
                required: string[];
                properties: {
                    validators: {
                        type: string;
                        fieldNumber: number;
                        items: {
                            type: string;
                            required: string[];
                            properties: {
                                address: {
                                    dataType: string;
                                    fieldNumber: number;
                                };
                                blsKey: {
                                    dataType: string;
                                    fieldNumber: number;
                                };
                                bftWeight: {
                                    dataType: string;
                                    fieldNumber: number;
                                };
                            };
                        };
                    };
                    certificateThreshold: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    validatorsHash: {
                        dataType: string;
                        fieldNumber: number;
                    };
                };
            };
        };
    };
};
export declare const lastSentCCMWithHeight: {
    $id: string;
    type: string;
    required: string[];
    properties: {
        height: {
            dataType: string;
            fieldNumber: number;
        };
        module: {
            dataType: string;
            minLength: number;
            maxLength: number;
            fieldNumber: number;
        };
        crossChainCommand: {
            dataType: string;
            minLength: number;
            maxLength: number;
            fieldNumber: number;
        };
        nonce: {
            dataType: string;
            fieldNumber: number;
        };
        fee: {
            dataType: string;
            fieldNumber: number;
        };
        sendingChainID: {
            dataType: string;
            minLength: number;
            maxLength: number;
            fieldNumber: number;
        };
        receivingChainID: {
            dataType: string;
            minLength: number;
            maxLength: number;
            fieldNumber: number;
        };
        params: {
            dataType: string;
            fieldNumber: number;
        };
        status: {
            dataType: string;
            fieldNumber: number;
        };
    };
};
export declare const listOfCCUsSchema: {
    $id: string;
    type: string;
    properties: {
        listOfCCUs: {
            type: string;
            fieldNumber: number;
            items: {
                $id: string;
                type: string;
                required: string[];
                properties: {
                    module: {
                        dataType: string;
                        fieldNumber: number;
                        minLength: number;
                        maxLength: number;
                    };
                    command: {
                        dataType: string;
                        fieldNumber: number;
                        minLength: number;
                        maxLength: number;
                    };
                    nonce: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    fee: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    senderPublicKey: {
                        dataType: string;
                        fieldNumber: number;
                        minLength: number;
                        maxLength: number;
                    };
                    params: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    signatures: {
                        type: string;
                        items: {
                            dataType: string;
                        };
                        fieldNumber: number;
                    };
                };
            };
        };
    };
};
export declare const ccmsFromEventsSchema: {
    $id: string;
    type: string;
    properties: {
        ccmsFromEvents: {
            type: string;
            fieldNumber: number;
            items: {
                type: string;
                required: string[];
                properties: {
                    ccms: {
                        type: string;
                        fieldNumber: number;
                        items: {
                            $id: string;
                            type: string;
                            required: string[];
                            properties: {
                                module: {
                                    dataType: string;
                                    minLength: number;
                                    maxLength: number;
                                    fieldNumber: number;
                                };
                                crossChainCommand: {
                                    dataType: string;
                                    minLength: number;
                                    maxLength: number;
                                    fieldNumber: number;
                                };
                                nonce: {
                                    dataType: string;
                                    fieldNumber: number;
                                };
                                fee: {
                                    dataType: string;
                                    fieldNumber: number;
                                };
                                sendingChainID: {
                                    dataType: string;
                                    minLength: number;
                                    maxLength: number;
                                    fieldNumber: number;
                                };
                                receivingChainID: {
                                    dataType: string;
                                    minLength: number;
                                    maxLength: number;
                                    fieldNumber: number;
                                };
                                params: {
                                    dataType: string;
                                    fieldNumber: number;
                                };
                                status: {
                                    dataType: string;
                                    fieldNumber: number;
                                };
                            };
                        };
                    };
                    height: {
                        dataType: string;
                        fieldNumber: number;
                    };
                    inclusionProof: {
                        type: string;
                        fieldNumber: number;
                        required: string[];
                        properties: {
                            siblingHashes: {
                                type: string;
                                fieldNumber: number;
                                items: {
                                    dataType: string;
                                };
                            };
                            bitmap: {
                                dataType: string;
                                fieldNumber: number;
                            };
                        };
                    };
                    outboxSize: {
                        dataType: string;
                        fieldNumber: number;
                    };
                };
            };
        };
    };
};
export declare const authorizeRequestSchema: {
    $id: string;
    type: string;
    required: string[];
    properties: {
        password: {
            type: string;
        };
        enable: {
            type: string;
        };
    };
};
