"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.bftParametersJSONToObj = exports.proveResponseJSONToObj = exports.chainAccountDataJSONToObj = exports.channelDataJSONToObj = exports.channelDataToJSON = exports.validatorsHashPreimagetoJSON = exports.ccmsFromEventsToJSON = exports.aggregateCommitToJSON = exports.getMainchainID = void 0;
const constants_1 = require("./constants");
const getMainchainID = (chainID) => {
    const networkID = chainID.slice(0, 1);
    return Buffer.concat([networkID, Buffer.alloc(constants_1.CHAIN_ID_LENGTH - 1, 0)]);
};
exports.getMainchainID = getMainchainID;
const aggregateCommitToJSON = (aggregateCommit) => ({
    height: aggregateCommit.height,
    aggregationBits: aggregateCommit.aggregationBits.toString('hex'),
    certificateSignature: aggregateCommit.certificateSignature.toString('hex'),
});
exports.aggregateCommitToJSON = aggregateCommitToJSON;
const ccmsFromEventsToJSON = (ccmsFromEvents) => ({
    ccms: ccmsFromEvents.ccms.map(ccm => ({
        ...ccm,
        fee: ccm.fee.toString(),
        nonce: ccm.nonce.toString(),
        params: ccm.params.toString('hex'),
        receivingChainID: ccm.receivingChainID.toString('hex'),
        sendingChainID: ccm.sendingChainID.toString('hex'),
    })),
    height: ccmsFromEvents.height,
    inclusionProof: {
        bitmap: ccmsFromEvents.inclusionProof.bitmap.toString('hex'),
        siblingHashes: ccmsFromEvents.inclusionProof.siblingHashes.map(s => s.toString('hex')),
    },
    outboxSize: ccmsFromEvents.outboxSize,
});
exports.ccmsFromEventsToJSON = ccmsFromEventsToJSON;
const validatorsHashPreimagetoJSON = (validatorsHashPreimage) => {
    const validatorsHashPreimageJSON = [];
    for (const validatorData of validatorsHashPreimage) {
        const validatorsJSON = validatorData.validators.map(v => ({
            address: v.address.toString('hex'),
            bftWeight: v.bftWeight.toString(),
            blsKey: v.blsKey.toString('hex'),
        }));
        validatorsHashPreimageJSON.push({
            certificateThreshold: validatorData.certificateThreshold.toString(),
            validators: validatorsJSON,
            validatorsHash: validatorData.validatorsHash.toString('hex'),
        });
    }
    return validatorsHashPreimageJSON;
};
exports.validatorsHashPreimagetoJSON = validatorsHashPreimagetoJSON;
const channelDataToJSON = (channelData) => {
    const { inbox, messageFeeTokenID, outbox, partnerChainOutboxRoot, minReturnFeePerByte } = channelData;
    const inboxJSON = {
        appendPath: inbox.appendPath.map(ap => ap.toString('hex')),
        root: inbox.root.toString('hex'),
        size: inbox.size,
    };
    const outboxJSON = {
        appendPath: outbox.appendPath.map(ap => ap.toString('hex')),
        root: outbox.root.toString('hex'),
        size: outbox.size,
    };
    return {
        messageFeeTokenID,
        outbox: outboxJSON,
        inbox: inboxJSON,
        partnerChainOutboxRoot: partnerChainOutboxRoot.toString('hex'),
        minReturnFeePerByte: minReturnFeePerByte.toString(),
    };
};
exports.channelDataToJSON = channelDataToJSON;
const channelDataJSONToObj = (channelData) => {
    const { inbox, messageFeeTokenID, outbox, partnerChainOutboxRoot, minReturnFeePerByte } = channelData;
    const inboxJSON = {
        appendPath: inbox.appendPath.map(ap => Buffer.from(ap, 'hex')),
        root: Buffer.from(inbox.root, 'hex'),
        size: inbox.size,
    };
    const outboxJSON = {
        appendPath: outbox.appendPath.map(ap => Buffer.from(ap, 'hex')),
        root: Buffer.from(outbox.root, 'hex'),
        size: outbox.size,
    };
    return {
        messageFeeTokenID: Buffer.from(messageFeeTokenID, 'hex'),
        outbox: outboxJSON,
        inbox: inboxJSON,
        partnerChainOutboxRoot: Buffer.from(partnerChainOutboxRoot, 'hex'),
        minReturnFeePerByte: BigInt(minReturnFeePerByte),
    };
};
exports.channelDataJSONToObj = channelDataJSONToObj;
const chainAccountDataJSONToObj = (chainAccountJSON) => {
    const { lastCertificate } = chainAccountJSON;
    return {
        ...chainAccountJSON,
        lastCertificate: {
            height: lastCertificate.height,
            stateRoot: Buffer.from(lastCertificate.stateRoot, 'hex'),
            timestamp: lastCertificate.timestamp,
            validatorsHash: Buffer.from(lastCertificate.validatorsHash, 'hex'),
        },
    };
};
exports.chainAccountDataJSONToObj = chainAccountDataJSONToObj;
const proveResponseJSONToObj = (proveResponseJSON) => {
    const { proof: { queries, siblingHashes }, } = proveResponseJSON;
    return {
        proof: {
            queries: queries.map(query => ({
                bitmap: Buffer.from(query.bitmap, 'hex'),
                key: Buffer.from(query.key, 'hex'),
                value: Buffer.from(query.value, 'hex'),
            })),
            siblingHashes: siblingHashes.map(siblingHash => Buffer.from(siblingHash, 'hex')),
        },
    };
};
exports.proveResponseJSONToObj = proveResponseJSONToObj;
const bftParametersJSONToObj = (bftParametersJSON) => {
    const { certificateThreshold, precommitThreshold, prevoteThreshold, validators, validatorsHash } = bftParametersJSON;
    return {
        certificateThreshold: BigInt(certificateThreshold),
        precommitThreshold: BigInt(precommitThreshold),
        prevoteThreshold: BigInt(prevoteThreshold),
        validators: validators.map(validator => ({
            address: Buffer.from(validator.address, 'hex'),
            bftWeight: BigInt(validator.bftWeight),
            blsKey: Buffer.from(validator.blsKey, 'hex'),
        })),
        validatorsHash: Buffer.from(validatorsHash, 'hex'),
    };
};
exports.bftParametersJSONToObj = bftParametersJSONToObj;
//# sourceMappingURL=utils.js.map