"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getForgerInfo = exports.setForgerInfo = exports.setForgerSyncInfo = exports.getForgerSyncInfo = exports.getDBInstance = void 0;
const createDebug = require("debug");
const lisk_sdk_1 = require("lisk-sdk");
const os = require("os");
const path_1 = require("path");
const fs_extra_1 = require("fs-extra");
const constants_1 = require("./constants");
const schemas_1 = require("./schemas");
const debug = createDebug('plugin:forger:db');
const { Database } = lisk_sdk_1.db;
const getDBInstance = async (dataPath, dbName = 'lisk-framework-forger-plugin.db') => {
    const dirPath = (0, path_1.join)(dataPath.replace('~', os.homedir()), 'plugins/data', dbName);
    await (0, fs_extra_1.ensureDir)(dirPath);
    return new Database(dirPath);
};
exports.getDBInstance = getDBInstance;
const getForgerSyncInfo = async (db) => {
    try {
        const encodedSyncInfo = await db.get(constants_1.DB_KEY_FORGER_SYNC_INFO);
        return lisk_sdk_1.codec.decode(schemas_1.forgerSyncSchema, encodedSyncInfo);
    }
    catch (error) {
        debug('Forger sync info does not exists');
        return {
            syncUptoHeight: 0,
        };
    }
};
exports.getForgerSyncInfo = getForgerSyncInfo;
const setForgerSyncInfo = async (db, blockHeight) => {
    const encodedSyncInfo = lisk_sdk_1.codec.encode(schemas_1.forgerSyncSchema, { syncUptoHeight: blockHeight });
    await db.set(constants_1.DB_KEY_FORGER_SYNC_INFO, encodedSyncInfo);
};
exports.setForgerSyncInfo = setForgerSyncInfo;
const setForgerInfo = async (db, forgerAddress, forgerInfo) => {
    const encodedForgerInfo = lisk_sdk_1.codec.encode(schemas_1.forgerInfoSchema, forgerInfo);
    await db.set(Buffer.concat([constants_1.DB_KEY_FORGER_INFO, Buffer.from(`:${forgerAddress}`, 'utf8')]), encodedForgerInfo);
};
exports.setForgerInfo = setForgerInfo;
const getForgerInfo = async (db, forgerAddress) => {
    let forgerInfo;
    try {
        forgerInfo = await db.get(Buffer.concat([constants_1.DB_KEY_FORGER_INFO, Buffer.from(`:${forgerAddress}`, 'utf8')]));
    }
    catch (error) {
        debug(`Forger info does not exists for validator: ${forgerAddress}`);
        return {
            totalProducedBlocks: 0,
            totalReceivedFees: BigInt(0),
            totalReceivedRewards: BigInt(0),
            stakeReceived: [],
        };
    }
    return lisk_sdk_1.codec.decode(schemas_1.forgerInfoSchema, forgerInfo);
};
exports.getForgerInfo = getForgerInfo;
//# sourceMappingURL=db.js.map