"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Endpoint = void 0;
const lisk_sdk_1 = require("lisk-sdk");
const db_1 = require("./db");
class Endpoint extends lisk_sdk_1.BasePluginEndpoint {
    init(db, apiClient) {
        this._db = db;
        this._client = apiClient;
    }
    async getStakers(_context) {
        const { status: forgersList } = await this._client.invoke('generator_getStatus');
        const forgerAccounts = [];
        for (const validator of forgersList) {
            const res = await this._client.invoke('pos_getValidator', {
                address: validator.address,
            });
            forgerAccounts.push({
                ...res,
                address: validator.address,
            });
        }
        const result = [];
        for (const account of forgerAccounts) {
            const forgerInfo = await (0, db_1.getForgerInfo)(this._db, Buffer.from(account.address, 'hex').toString('binary'));
            result.push({
                address: account.address,
                username: account.name,
                totalStakeReceived: account.totalStakeReceived,
                stakers: forgerInfo.stakeReceived.map(stake => ({
                    address: lisk_sdk_1.cryptography.address.getLisk32AddressFromAddress(stake.address),
                    amount: stake.amount.toString(),
                })),
            });
        }
        return result;
    }
    async getForgingInfo(_context) {
        const { status: forgersList } = await this._client.invoke('generator_getStatus');
        const forgerAccounts = [];
        for (const validator of forgersList) {
            const res = await this._client.invoke('pos_getValidator', {
                address: validator.address,
            });
            forgerAccounts.push({
                ...res,
                address: validator.address,
            });
        }
        const data = [];
        for (const forgerAccount of forgerAccounts) {
            const forgerAddressBinary = Buffer.from(forgerAccount.address, 'hex').toString('binary');
            const forgerInfo = await (0, db_1.getForgerInfo)(this._db, forgerAddressBinary);
            const forger = forgersList.find(aForger => aForger.address === forgerAccount.address);
            if (forger) {
                data.push({
                    ...forger,
                    username: forgerAccount.name,
                    totalReceivedFees: forgerInfo.totalReceivedFees.toString(),
                    totalReceivedRewards: forgerInfo.totalReceivedRewards.toString(),
                    totalProducedBlocks: forgerInfo.totalProducedBlocks,
                    totalStakeReceived: forgerAccount.totalStakeReceived,
                    consecutiveMissedBlocks: forgerAccount.consecutiveMissedBlocks,
                });
            }
        }
        return data;
    }
}
exports.Endpoint = Endpoint;
//# sourceMappingURL=endpoint.js.map