"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ShowCommand = void 0;
const utils = require("@liskhq/lisk-utils");
const core_1 = require("@oclif/core");
const fs = require("fs-extra");
const flags_1 = require("../../../utils/flags");
const path_1 = require("../../../utils/path");
class ShowCommand extends core_1.Command {
    async run() {
        const { flags } = await this.parse(ShowCommand);
        const dataPath = flags['data-path']
            ? flags['data-path']
            : (0, path_1.getDefaultPath)(this.config.pjson.name);
        const { configFilePath } = (0, path_1.getConfigFilesPath)(dataPath);
        if (!fs.existsSync(configFilePath)) {
            this.error(`Folder in ${dataPath} does not contain valid config`);
        }
        let config = (await fs.readJSON(configFilePath));
        if (flags.config) {
            const customConfig = (await fs.readJSON(flags.config));
            config = utils.objects.mergeDeep({}, config, customConfig);
        }
        config.system.dataPath = dataPath;
        if (flags.pretty) {
            this.log(JSON.stringify(config, undefined, '  '));
        }
        else {
            this.log(JSON.stringify(config));
        }
    }
}
ShowCommand.description = 'Show application config.';
ShowCommand.examples = [
    'config:show',
    'config:show --pretty',
    'config:show --config ./custom-config.json --data-path ./data',
];
ShowCommand.flags = {
    'data-path': flags_1.flagsWithParser.dataPath,
    config: flags_1.flagsWithParser.config,
    pretty: flags_1.flagsWithParser.pretty,
};
exports.ShowCommand = ShowCommand;
//# sourceMappingURL=show.js.map