"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MetadataCommand = void 0;
const base_ipc_client_1 = require("../base_ipc_client");
class MetadataCommand extends base_ipc_client_1.BaseIPCClientCommand {
    async run() {
        if (!this._client) {
            this.error('APIClient is not initialized.');
        }
        try {
            const metadataInfo = await this._client.invoke('system_getMetadata');
            this.printJSON(metadataInfo);
        }
        catch (errors) {
            const errorMessage = Array.isArray(errors)
                ? errors.map(err => err.message).join(',')
                : errors;
            this.error(errorMessage);
        }
    }
}
MetadataCommand.description = 'Get node metadata from a running application.';
MetadataCommand.examples = ['system:metadata', 'system:metadata --data-path ./lisk'];
MetadataCommand.flags = {
    ...base_ipc_client_1.BaseIPCClientCommand.flags,
};
exports.MetadataCommand = MetadataCommand;
//# sourceMappingURL=metadata.js.map