"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.readGenesisBlock = void 0;
const fs = require("fs");
const lisk_chain_1 = require("@liskhq/lisk-chain");
const path_1 = require("./path");
const readGenesisBlock = (config, logger) => {
    if (config.genesis.block.blob) {
        logger.debug('Reading genesis block from blob hex string');
        return lisk_chain_1.Block.fromBytes(Buffer.from(config.genesis.block.blob, 'hex'));
    }
    if (config.genesis.block.fromFile) {
        const filePath = (0, path_1.getPathFromDataPath)(config.genesis.block.fromFile, config.system.dataPath);
        logger.debug({ fromFile: filePath }, 'Reading genesis block from file');
        const genesisBlob = fs.readFileSync(filePath);
        return lisk_chain_1.Block.fromBytes(genesisBlob);
    }
    throw new Error('Genesis block information is required');
};
exports.readGenesisBlock = readGenesisBlock;
//# sourceMappingURL=genesis_block.js.map